@@ -240,12 +240,11 @@ impl Options {
         let enable_simplifier = optimizer.as_ref().map(|v| v.simplify).unwrap_or_default();
 
         let optimization = {
-            let pass =
-                if let Some(opts) = optimizer.map(|o| o.globals.unwrap_or_else(Default::default)) {
-                    opts.build(cm, handler)
-                } else {
-                    GlobalPassOption::default().build(cm, handler)
-                };
+            let pass = if let Some(opts) = optimizer.and_then(|o| o.globals) {
+                Either::Left(opts.build(cm, handler))
+            } else {
+                Either::Right(noop())
+            };
 
             pass
         };
@@ -527,6 +526,9 @@ pub struct Config {
 
     #[serde(default = "true_by_default")]
     pub inline_sources_content: bool,
+
+    #[serde(default)]
+    pub error: ErrorConfig,
 }
 
 /// Second argument of `minify`.
@@ -989,6 +991,13 @@ fn default_jsonify_min_cost() -> usize {
     1024
 }
 
+#[derive(Debug, Default, Clone, Copy, Serialize, Deserialize)]
+#[serde(deny_unknown_fields, rename_all = "camelCase")]
+pub struct ErrorConfig {
+    #[serde(default = "true_by_default")]
+    pub filename: bool,
+}
+
 #[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(deny_unknown_fields, rename_all = "camelCase")]
 pub struct GlobalPassOption {
